@@ -3,11 +3,11 @@
 /*		A little program to send commands to the modem		*/
 /*		with special features for voice modems.			*/
 /*									*/
-/* Version	0.6		Sep 8 1997				*/
+/* Version	0.6.1		Jul 14 1999				*/
 /*									*/
 /* Author:	Niccolo Rigacci <fd131@cleveland.freenet.edu>		*/
 /*									*/
-/* Copyright (C) 1996 Niccolo Rigacci					*/
+/* Copyright (C) 1996-1999 Niccolo Rigacci				*/
 /*									*/
 /* This program is free software; you can redistribute it and/or modify	*/
 /* it under the terms of the GNU General Public License as published by	*/
@@ -31,7 +31,7 @@
 #include <getopt.h>
 #include <signal.h>
 #include <string.h>
-#include <termios.h>
+#include <linux/termios.h>
 #include <unistd.h>
 #include <sys/file.h>
 #include <sys/stat.h>
@@ -118,7 +118,7 @@ long baud_rate;				/* Baud rate of serial line	*/
 /*----------------------------------------------------------------------*/
 /* Main program
 /*----------------------------------------------------------------------*/
-void main(int argc, char **argv)
+int main(int argc, char **argv)
    {
    int i, c, fd, opt;
    int eof_inp = TRUE;
